@@ -5,15 +5,15 @@ import time
 
 def news_crawler():
     db_sitemap = {x[0]: x for x in get_all_sitemap()}
-    trust_levels = {x[0]: x for x in get_trust_levels()}
+    trust_levels = {x[0]: x[1] for x in get_trust_levels()}
     for parent in get_sitemap_parent():
         elastic_sitemap(parent, trust_levels, db_sitemap, sort='loc', influxdb=True)
 
 
 def scheduler_news():
     print('Start crawler/indexer sitemap')
-    start = time.time()
     while True:
+        start = time.time()
         try:
             news_crawler()
         except Exception as error:
